@@ -1,16 +1,24 @@
+import enum
+import typing
 import configparser
 from importlib import resources
 from functools import lru_cache
-from types import MappingProxyType
+
+
+class _TokenID(typing.NamedTuple):
+    description: str
+    short_name: str
+    pattern: str = r'\w+'
+    default: str = ''
 
 
 @lru_cache()
 def __getattr__(name):
     cfg_fname = f'{name}.cfg'
     if resources.is_resource(__name__, cfg_fname):
-        cfg = configparser.ConfigParser({'default': '', 'pattern': '\w+'})
+        cfg = configparser.ConfigParser()
         cfg.read_string(resources.read_text(__name__, cfg_fname))
-        return MappingProxyType({s: MappingProxyType(dict(cfg[s])) for s in cfg.sections()})
+        return enum.Enum(name, ((s, _TokenID(**cfg[s])) for s in cfg.sections()))
     raise AttributeError(f"module {__name__} has no attribute {name}")
 
 
